#
# spec file for package libmwaw
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define libname libmwaw-0_3-3
Name:           libmwaw
Version:        0.3.21
Release:        3.3
Summary:        Pre Mac OSX text file formats parser library
License:        GPL-2.0-or-later AND (LGPL-2.1-or-later OR MPL-2.0)
URL:            https://sourceforge.net/p/libmwaw/wiki/Home/
Source:         https://dev-www.libreoffice.org/src/%{name}-%{version}.tar.xz
Patch0:         fix-build.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
Libmwaw is a project for converting many pre-OSX MAC text formats.

%package -n %{libname}
Summary:        Pre Mac OSX text file formats parser library

%description -n %{libname}
Libmwaw is a new project for converting many pre-OSX MAC text formats.

%package devel
Summary:        Files for Developing with libmwaw
Requires:       %{libname} = %{version}

%description devel
Libmwaw is a new project for converting many pre-OSX MAC text formats.
This package contains the libmwaw development files.

%package devel-doc
Summary:        Documentation for the libmwaw API
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libmwaw API.

%package tools
Summary:        Tools to work with publications in pre MAC OSX text file-formats

%description tools
Command line tools to work with publications in pre MAC OSX text file-formats.

%prep
%autosetup -p1

# doxygen needles rebuild
sed -i \
	-e 's:on $datetime::g' \
	docs/doxygen/footer.html.in

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-silent-rules \
	--disable-werror \
	--disable-static \
	--docdir=%{_docdir}/%{name}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -p COPYING.* %{buildroot}%{_docdir}/%{name}
# docs have duped pictures
%fdupes %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/libmwaw*.pc
%{_includedir}/libmwaw-*

%files devel-doc
%doc %{_docdir}/%{name}/html

%files tools
%{_bindir}/*
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/[A-Z]*

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Jan 27 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * fix-build.patch
    + Fix build with older compilers by helping to resolve type
    ambiguity.
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.3.21:
  * add debug code to read some private rsrc data
  + allow to read some MacWrite which does not have printer informations
  * add a parser for Scoop files
  * add a parser for ScriptWriter files
  * add a parser for ReadySetGo 1-4 files
* Fri Sep 17 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.3.20:
  * add a parser for Student Writing Center files (v1)
  * add a parser for Word Maker files (v1)
  * add a parser for Canvas 9/10 files (Mac)
* Fri Jul 16 2021 Dirk Müller <dmueller@suse.com>
- update to 0.3.19:
  - add a parser for Canvas 7/8 files (Mac)
  - add a parser for Canvas Image files (Mac 5-8, Windows 5-6)
  - add a parser for Canvas 6 (Mac and Windows)
  - remove many coverity warnings
  - add a parser for Canvas 5 ( Mac and Windows )
  - add basic support for hatch
  - add basic support for drop cap
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Mon Jan 18 2021 Dirk Müller <dmueller@suse.com>
- update to 0.3.17:
  - add a parser for Jazz(Lotus) writer and spreasheet files
    + the writer parser can only be called if the file still
    contains its resource fork
  - add a parser for Canvas 3 and 3.5 files
  - AppleWorks parser: try to retrieve more Windows presentation
  - add a parser for Drawing Table files
  - add a parser for Canvas 2 files
  - configure.ac: add an enable-asan option
  - API: add new reserved enums in MWAWDocument.hxx
    MWAW_T_RESERVED10..MWAW_T_RESERVED29
    and add a new define in libmwaw.hxx
    MWAW_INTERFACE_VERSION
    to check if these enums are defined
* Thu Jun 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.16:
  - remove the QuarkXPress parser (must be in libqxp)
  - retrieve the annotation in MsWord 5 document
  - try to better understand RagTime 5-6 document
  - add a parser for QuarkXPress v1-2 files
* Tue Apr 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.15:
  * Use zlib more
  * Fuzzing fixes
* Wed May 30 2018 tchvatal@suse.com
- Update to 0.3.14:
  * Support MS Multiplan 1.1 files
- Remove merged patch libmwaw-0.3.13-buildfix.patch
* Tue Dec  5 2017 tchvatal@suse.com
- Add patch to build with old gcc:
  * libmwaw-0.3.13-buildfix.patch
* Wed Nov 29 2017 tchvatal@suse.com
- Version update to 0.3.13:
  * Remove merged CVE-2017-9433.patch
  * Many fuzzing fixes
* Thu Jun 29 2017 tchvatal@suse.com
- Add patch CVE-2017-9433.patch fixing bsc#1042828 CVE-2017-9433
* Mon May 15 2017 tchvatal@suse.com
- Update to 0.3.11:
  * Various small updates
* Thu Feb  9 2017 tchvatal@suse.com
- Version update to 0.3.10:
  * Various fixes for importing Mac powerpoint v4
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Dec  3 2016 tchvatal@suse.com
- Version update to 0.3.9:
  * Various warning and clang fixes all around
* Thu Jul 14 2016 tchvatal@suse.com
- Version update to 0.3.8:
  * Various clang and -W* fixes all around
  * Bunch of bugfixes
* Mon Dec 21 2015 tchvatal@suse.com
- Version update to 0.3.7:
  - RagTime v5-v6 parser: try to retrieve the embedded spreadsheets
    + begin to understand the hierarchical structures which store
    a chart (but not the meaning of each field),
  - ClarisWorks/AppleWorks: find a new structure in the file's header
    (which could prevent to convert some database's file),
  - BeagleWorks/GreatWorks/Word Perfect Works: retrieve the picture's
    field in a database
  - all: improve a little the methods which create spreadsheets,
  - all: make some constructors explicit.
  - add a parser for Style documents(at least v1.6 and v1.9)
  - add file signatures for FullPaint documents which have the same format as
    MacPaint..
  - add a parser for Pixel Paint documents
* Fri Aug 28 2015 tchvatal@suse.com
- Version bump to 0.3.6:
  - Added a minimal parser for ApplePict v1.v2, ie. no clipping, does not
    take in account the copy mode: srcCopy, srcOr, ...
  - Extended the --with-docs configure option to allow to build doc only
    for the API classes: --with-docs=no|api|full .
  - Added a parser for MacDraft v4-v5 documents.
  - RagTime v5-v6 parser: try to retrieve the main layouts and the
    picture/shape/textbox, ie. now, it generates result but it is
    still very imcomplete...
  - MWAW{Graphic,Presentation,Text}Listener: corrected a problem in openGroup
    which may create to incorrect document.
  - Created an MWAWEmbeddedObject class to store a picture with various
    representations.
  - MWAW*Listener: renamed insertPicture to insertShape, added a function to
    insert a texbox in a MWAWGraphicShape (which only insert a basic textbox).
  - Fixed many crashes and hangs when importing broken files, found with the
    help of american-fuzzy-lop.
  - And several other minor fixes and improvements.
* Sat Jun 13 2015 tchvatal@suse.com
- Version bump to 0.3.5
  * Various small fixes on 0.3 series, nothing big woth mention
* Fri Jan  2 2015 tchvatal@suse.com
- Version bump to 0.3.4:
  * Various tweaks&fixes on the 0.3 series found by fuzzy testing/etc
- Removed patch libmwaw-0.3.1-stream.patch as we should not bother
  with old autotools
* Tue Jul  1 2014 fstrba@suse.com
- Fix patch libmwaw-0.3.1-stream.patch to allow buiding with older
  version of autotools.
* Wed Jun 11 2014 tchvatal@suse.com
- Version bump to 0.3.1:
  * Switch over to librevenge framework
- Add patch libmwaw-0.3.1-stream.patch to fix streams
* Sat Jan 25 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and noarch documenation.
* Sat Jan 18 2014 crrodriguez@opensuse.org
- build with -fvisibility-inlines-hidden, around 2800
  less in the export symbol table.
* Tue Dec 17 2013 fridrich.strba@suse.com
- Upgrade to upstream 0.2.0
  - ABI change
  - Several improvements in handling of embedded graphics
* Tue Dec  3 2013 tchvatal@suse.com
- Format with spec-cleaner
* Fri Nov  1 2013 tchvatal@suse.com
- Drop doc conditional and use verbose build.
* Mon May 27 2013 tchvatal@suse.com
- Version bump to 0.1.9 providing following fixes:
  - improve a little the Microsoft Word filter to better manage
  character and paragraph properties
  - check that the remaining parsers (excepted Microsoft Word) use the
  new properties' classes,
  - add table generation in FullWrite parser,
  - rewrite from scratch zip.cpp (to avoid using different license),
  - + many code corrections done by David Tardon.
  - check that the WriterPlus parsers use the new properties' classes,
  - simplify a little the code of MWAWDocument
  - add a parser for Acta v2 and Acta Classic v1,
  - check that the DOCMaker, eDOC, SimpleText, Tex-Edit, Z-Write parsers
  use the new properties' classes,
  - rewrite MWAWPageSpan,
  - add classes MWAWField, MWAWNote, MWAWSection to store/manage
  field, note, section properties,
  - check that the ClarisWorks/AppleWorks, MacWrite, MindWrite,
  WriteNow parsers use the new properties' classes,
  - improve a little the ClarisWorks/AppleWorks frame position by
  placing <<correctly>> all page's frames,
  - MWAWContentListener : add a sanity check to insure that at most
  200 very small pictures are generated.
* Sun Apr 28 2013 fridrich.strba@suse.com
- Upgrade to upstream 0.1.8
  - Several improvements in different parsers
* Sat Apr 20 2013 tchvatal@suse.com
- Use download URL path.
* Tue Mar 26 2013 cfarrell@suse.com
- license update: (LGPL-2.1+ or MPL-2.0) and GPL-2.0+
  Most of package is dual MPL-2.0 or LGPL-2.1+ but tools/zip is GPL-2.0+
* Wed Mar 13 2013 tchvatal@suse.com
- Initial package of libmwaw. Required by libreoffice-4.1
